intelmq.bots.collectors.blueliv package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.collectors.blueliv package

## Submodules

## intelmq.bots.collectors.blueliv.collector_crimeserver module

`intelmq.bots.collectors.blueliv.collector_crimeserver.` `BOT`

  alias of `intelmq.bots.collectors.blueliv.collector_crimeserver.BluelivCrimeserverCollectorBot`

class `intelmq.bots.collectors.blueliv.collector_crimeserver.` `BluelivCrimeserverCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  Collect reports from the Blueliv Crimeserver API

  `api_key`: str = '<insert your api key>'
  `api_url`: str = 'https://freeapi.blueliv.com'
  `init`()
  `process`()
  `rate_limit`: int = 3600

## Module contents